@@ -783,19 +783,19 @@ else
 switch(*bc)     {
 
         case PERIODIC:  /* Periodic boundary conditions */
-                if (verbose) printf("Periodic boundary method\n");
+                if (verbose) Rprintf("Periodic boundary method\n");
                 break;
 
         case SYMMETRIC: /* Symmetric boundary conditions */
-                if (verbose) printf("Symmetric boundary method\n");
+                if (verbose) Rprintf("Symmetric boundary method\n");
                 break;
 
         case ZERO:  /* Zero boundary conditions */
-        if (verbose) printf("Zero boundary method\n");
+        if (verbose) Rprintf("Zero boundary method\n");
         break;
 
         default:        /* The bc must be one of the above */
-                printf("Unknown boundary correction method\n");
+                Rprintf("Unknown boundary correction method\n");
                 *error = 1;
                 return;
         }
@@ -803,20 +803,20 @@ switch(*bc)     {
 switch(*type)   {
 
         case WAVELET:   /* Standard wavelets */
-                if (verbose) printf("Standard wavelet decomposition\n");
+                if (verbose) Rprintf("Standard wavelet decomposition\n");
                 break;
 
         case STATION:   /* Stationary wavelets */
-                if (verbose) printf("Stationary wavelet decomposition\n");
+                if (verbose) Rprintf("Stationary wavelet decomposition\n");
                 break;
 
         default:        /* The type must be of one the above */
-                if (verbose) printf("Unknown decomposition type\n");
+                if (verbose) Rprintf("Unknown decomposition type\n");
                 *error = 2;
                 return;
         }
 
-if (verbose) printf("Decomposing into level: ");
+if (verbose) Rprintf("Decomposing into level: ");
 
 *error = 0l;
 
@@ -828,7 +828,7 @@ step_factor = 1;        /* This variable should *always* be 1 for standard
 for(next_level = *levels - 1; next_level >= 0; --next_level)    {
 
         if (verbose)
-                printf("%d ", next_level);
+                Rprintf("%d ", next_level);
 
         at_level = next_level + 1;
 
@@ -862,7 +862,7 @@ for(next_level = *levels - 1; next_level >= 0; --next_level)    {
                                          * know what to do here ! */
         }
 if (verbose)
-        printf("\n");
+        Rprintf("\n");
 return;
 }
 
@@ -1047,10 +1047,11 @@ else if (n<0)   {
                 */
                 n = n%lengthC + lengthC*((n%lengthC)!=0);
                 if (n < 0)      {
-                        fprintf(stderr, "reflect: access error (%d,%d)\n",
+                        REprintf("reflect: access error (%d,%d)\n",
                                 n,lengthC);
-                        fprintf(stderr, "reflect: left info from right\n");
-                        exit(2);
+                        REprintf("reflect: left info from right\n");
+                        
+			error("This should not happen: stopping.\n");
                         }
                 else
                         return(n);
@@ -1059,18 +1060,18 @@ else if (n<0)   {
         else if (bc==SYMMETRIC) {
                 n = -1-n;
                 if (n >= lengthC)       {
-                        fprintf(stderr, "reflect: access error (%d,%d)\n",
+                        REprintf("reflect: access error (%d,%d)\n",
                                 n,lengthC);
-                        exit(3);
+			error("This should not happen: stopping.\n");
                         }
                 else
                         return(n);
                 }
 
         else    {
-                fprintf(stderr, "reflect: Unknown boundary correction");
-                fprintf(stderr, " value of %d\n", bc);
-                exit(4);
+                REprintf("reflect: Unknown boundary correction");
+                REprintf(" value of %d\n", bc);
+		error("This should not happen: stopping.\n");
                 }
 
         }
@@ -1085,10 +1086,10 @@ else    {
                 printf("%d\n", n);
                 */
                 if (n >= lengthC)       {
-                        fprintf(stderr, "reflect: access error (%d,%d)\n",
+                        REprintf("reflect: access error (%d,%d)\n",
                                 n,lengthC);
-                        fprintf(stderr, "reflect: right info from left\n");
-                        exit(5);
+                        REprintf("reflect: right info from left\n");
+			error("This should not happen: stopping.\n");
                         }
                 else
                         return(n);
@@ -1096,23 +1097,23 @@ else    {
         else if (bc==SYMMETRIC) {
                 n = 2*lengthC - n - 1;
                 if (n<0)        {
-                        fprintf(stderr, "reflect: access error (%d,%d)\n",
+                        REprintf("reflect: access error (%d,%d)\n",
                                 n,lengthC);
-                        exit(6);
+			error("This should not happen: stopping.\n");
                         }
                 else
                         return(n);
                 }
         else    {
-                fprintf(stderr, "reflect: Unknown boundary correction\n");
-                exit(7);
+                REprintf("reflect: Unknown boundary correction\n");
+		error("This should not happen: stopping.\n");
                 }
 
 
         }
 /* Safety */
-fprintf(stderr, "reflect: SHOULD NOT HAVE REACHED THIS POINT\n");
-exit(8);
+REprintf("reflect: SHOULD NOT HAVE REACHED THIS POINT\n");
+error("This should not happen: stopping.\n");
 return(0); /* for lint only */
 }
 
@@ -1164,19 +1165,19 @@ else
 switch(*bc)     {
 
         case PERIODIC:  /* Periodic boundary conditions */
-                if (verbose) printf("Periodic boundary method\n");
+                if (verbose) Rprintf("Periodic boundary method\n");
                 break;
 
         case SYMMETRIC: /* Symmetric boundary conditions */
-                if (verbose) printf("Symmetric boundary method\n");
+                if (verbose) Rprintf("Symmetric boundary method\n");
                 break;
 
         case ZERO: /*Zero boundary conditions */
-                if (verbose) printf("Zero boundary method\n");
+                if (verbose) Rprintf("Zero boundary method\n");
                 break;
 
         default:        /* The bc must be one of the above */
-                printf("Unknown boundary correction method\n");
+                Rprintf("Unknown boundary correction method\n");
                 *error = 1;
                 return;
         }
@@ -1184,20 +1185,20 @@ switch(*bc)     {
 switch(*type)   {
 
         case WAVELET:   /* Standard wavelets */
-                if (verbose) printf("Standard wavelet decomposition\n");
+                if (verbose) Rprintf("Standard wavelet decomposition\n");
                 break;
 
         case STATION:   /* Stationary wavelets */
-                if (verbose) printf("Stationary wavelet decomposition\n");
+                if (verbose) Rprintf("Stationary wavelet decomposition\n");
                 break;
 
         default:        /* The type must be of one the above */
-                if (verbose) printf("Unknown decomposition type\n");
+                if (verbose) Rprintf("Unknown decomposition type\n");
                 *error = 2;
                 return;
         }
 
-if (verbose) printf("Building level: ");
+if (verbose) Rprintf("Building level: ");
 
 *error = 0l;
 
@@ -1205,7 +1206,7 @@ for(next_level = 1; next_level <= *levels; ++next_level)        {
 
 
         if (verbose)
-                printf("%d ", next_level);
+                Rprintf("%d ", next_level);
 
         at_level = next_level - 1;
 
@@ -1225,7 +1226,7 @@ for(next_level = 1; next_level <= *levels; ++next_level)        {
                 (int)(*bc) );
         }
 if (verbose)
-        printf("\n");
+        Rprintf("\n");
 
 return;
 }
